@@ -1,10 +1,9 @@
-from random import SystemRandom
+import secrets
 from string import digits, ascii_letters
 
 
 ALPHABET = digits + ascii_letters
-RANDOM = SystemRandom()
 
 
 def make_random_string(length, alphabet=ALPHABET):
-    return ''.join(RANDOM.choice(alphabet) for _ in range(length))
+    return ''.join(secrets.choice(alphabet) for _ in range(length))
